@@ -1,8 +1,20 @@
 #include "MainWindow.h"
 
+#include <QVBoxLayout>
+#include <QMenuBar>
+
+#include <QDBusConnection>
+#include <QSettings>
+
+#include <CMulticalendar.h>
+
+#include "SettingsDialog.h"
+
+#include "ChangeManager.h"
 #include "Rotator.h"
 
-MainWindow::MainWindow()
+MainWindow::MainWindow(bool runInBackground) :
+    runInBackground(runInBackground)
 {
     this->setAttribute(Qt::WA_Maemo5StackedWindow);
 
@@ -82,6 +94,23 @@ MainWindow::MainWindow()
         showTodos();
     else if (view == "journals")
         showJournals();
+
+    if (runInBackground) {
+        QDBusConnection::sessionBus().registerService("com.nokia.calendar");
+        QDBusConnection::sessionBus().registerObject("/com/nokia/calendar", this, QDBusConnection::ExportScriptableSlots);
+    } else {
+        show();
+    }
+}
+
+void MainWindow::closeEvent(QCloseEvent *e)
+{
+    if (runInBackground) {
+        this->hide();
+        e->ignore();
+    } else {
+        QMainWindow::closeEvent(e);
+    }
 }
 
 // Forward activation events to the current plug
@@ -205,3 +234,37 @@ void MainWindow::openSettings()
 {
     (new SettingsDialog(this))->exec();
 }
+
+void MainWindow::top_application()
+{
+    // As long as checking for external updates to the database is not
+    // implemented, scheduling a refresh each time the window is shown is
+    // probably a good idea.
+    if (this->isHidden())
+        ChangeManager::bump();
+
+    this->show();
+    this->raise();
+    this->activateWindow();
+}
+
+void MainWindow::launch_view(uint type, int, QString componentId, int calendarId)
+{
+    // Some tests show that the second argument can have following values:
+    // * launching from desktop widget -> current timestamp
+    // * viewing an event from alarm dialog -> -1
+    // * viewing a todo from alarm dialog -> -2
+
+    Q_UNUSED(componentId);
+    Q_UNUSED(calendarId);
+
+    switch (type) {
+        case 1: showMonth(); break;
+        case 2: showWeek(); break;
+        case 3: showAgenda(); break;
+        case 4: showAgenda(); break; // TODO: Open EventWindow
+        case 5: showTodos(); break;  // TODO: Open TodoWindow
+    }
+
+    top_application();
+}
