@@ -1,32 +1,32 @@
+#ifndef MAINWINDOW_H
+#define MAINWINDOW_H
+
 #include <QMainWindow>
 
-#include <QVBoxLayout>
-#include <QMenuBar>
 #include <QMenu>
 
 #include <QDate>
 
-#include <QSettings>
-
-#include <calendar-backend/CMulticalendar.h>
-
 #include "MonthPlug.h"
 #include "WeekPlug.h"
 #include "AgendaPlug.h"
 #include "TodosPlug.h"
 #include "JournalsPlug.h"
 
-#include "SettingsDialog.h"
-
 class MainWindow : public QMainWindow
 {
     Q_OBJECT
+    Q_CLASSINFO("D-Bus Interface", "com.nokia.calendar")
 
 public:
-    MainWindow();
+    MainWindow(bool runInBackground);
 
     void setPlug(Plug *plug);
 
+public slots:
+    Q_SCRIPTABLE void top_application();
+    Q_SCRIPTABLE void launch_view(uint type, int, QString componentId, int calendarId = 0);
+
 private:
     QMenu *windowMenu;
 
@@ -49,6 +49,9 @@ private:
 
     QLayout *mainLayout;
 
+    bool runInBackground;
+
+    void closeEvent(QCloseEvent *e);
     void changeEvent(QEvent *e);
 
     void deleteOldComponents();
@@ -62,3 +65,5 @@ private slots:
 
     void openSettings();
 };
+
+#endif // MAINWINDOW_H
