@@ -15,7 +15,7 @@
     </message>
     <message>
         <location filename="../AgendaPlug.cpp" line="28"/>
-        <location filename="../AgendaPlug.cpp" line="125"/>
+        <location filename="../AgendaPlug.cpp" line="122"/>
         <source>New event</source>
         <translation>Uusi tapahtuma</translation>
     </message>
@@ -33,22 +33,22 @@
         <translation>Hälytys</translation>
     </message>
     <message>
-        <location filename="../AlarmPickDialog.ui" line="17"/>
+        <location filename="../AlarmPickDialog.ui" line="27"/>
         <source>Hours</source>
         <translation>Tunnit</translation>
     </message>
     <message>
-        <location filename="../AlarmPickDialog.ui" line="37"/>
+        <location filename="../AlarmPickDialog.ui" line="47"/>
         <source>Minutes</source>
         <translation>Minuutit</translation>
     </message>
     <message>
-        <location filename="../AlarmPickDialog.ui" line="57"/>
+        <location filename="../AlarmPickDialog.ui" line="67"/>
         <source>Seconds</source>
         <translation>Sekunnit</translation>
     </message>
     <message>
-        <location filename="../AlarmPickDialog.ui" line="77"/>
+        <location filename="../AlarmPickDialog.ui" line="17"/>
         <source>Enable</source>
         <translation>Ota käyttöön</translation>
     </message>
@@ -258,7 +258,7 @@
 <context>
     <name>ComponentListDelegate</name>
     <message>
-        <location filename="../ComponentListDelegate.h" line="79"/>
+        <location filename="../ComponentListDelegate.h" line="80"/>
         <source>All
 day</source>
         <translation>Koko
@@ -345,7 +345,7 @@ päivä</translation>
         <translation>Siirry</translation>
     </message>
     <message>
-        <location filename="../DayWindow.cpp" line="37"/>
+        <location filename="../DayWindow.cpp" line="36"/>
         <source>New event</source>
         <translation>Uusi tapahtuma</translation>
     </message>
@@ -512,22 +512,22 @@ päivä</translation>
 <context>
     <name>JournalsPlug</name>
     <message>
-        <location filename="../JournalsPlug.cpp" line="28"/>
+        <location filename="../JournalsPlug.cpp" line="27"/>
         <source>New note</source>
         <translation>Uusi muistiinpano</translation>
     </message>
     <message>
-        <location filename="../JournalsPlug.cpp" line="50"/>
+        <location filename="../JournalsPlug.cpp" line="46"/>
         <source>Notes</source>
         <translation>Muistiinpanot</translation>
     </message>
     <message>
-        <location filename="../JournalsPlug.cpp" line="124"/>
+        <location filename="../JournalsPlug.cpp" line="120"/>
         <source>Edit</source>
         <translation>Muokkaa</translation>
     </message>
     <message>
-        <location filename="../JournalsPlug.cpp" line="125"/>
+        <location filename="../JournalsPlug.cpp" line="121"/>
         <source>Delete</source>
         <translation>Poista</translation>
     </message>
@@ -535,32 +535,32 @@ päivä</translation>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../MainWindow.cpp" line="44"/>
+        <location filename="../MainWindow.cpp" line="56"/>
         <source>Month</source>
         <translation>Kuukausi</translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="45"/>
+        <location filename="../MainWindow.cpp" line="57"/>
         <source>Week</source>
         <translation>Viikko</translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="46"/>
+        <location filename="../MainWindow.cpp" line="58"/>
         <source>Agenda</source>
         <translation>Merkinnät</translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="47"/>
+        <location filename="../MainWindow.cpp" line="59"/>
         <source>Tasks</source>
         <translation>Tehtävät</translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="48"/>
+        <location filename="../MainWindow.cpp" line="60"/>
         <source>Notes</source>
         <translation>Muistiinpanot</translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="49"/>
+        <location filename="../MainWindow.cpp" line="61"/>
         <source>Settings</source>
         <translation>Asetukset</translation>
     </message>
@@ -568,27 +568,27 @@ päivä</translation>
 <context>
     <name>MonthPlug</name>
     <message>
-        <location filename="../month/MonthPlug.cpp" line="61"/>
+        <location filename="../month/MonthPlug.cpp" line="63"/>
         <source>Previous month</source>
         <translation>Edellinen kuukausi</translation>
     </message>
     <message>
-        <location filename="../month/MonthPlug.cpp" line="62"/>
+        <location filename="../month/MonthPlug.cpp" line="64"/>
         <source>Next month</source>
         <translation>Seuraava kuukausi</translation>
     </message>
     <message>
-        <location filename="../month/MonthPlug.cpp" line="63"/>
+        <location filename="../month/MonthPlug.cpp" line="65"/>
         <source>Jump to today</source>
         <translation>Siirry tähän päivään</translation>
     </message>
     <message>
-        <location filename="../month/MonthPlug.cpp" line="64"/>
+        <location filename="../month/MonthPlug.cpp" line="66"/>
         <source>Jump to</source>
         <translation>Siirry</translation>
     </message>
     <message>
-        <location filename="../month/MonthPlug.cpp" line="65"/>
+        <location filename="../month/MonthPlug.cpp" line="67"/>
         <source>New event</source>
         <translation>Uusi tapahtuma</translation>
     </message>
@@ -619,47 +619,47 @@ päivä</translation>
         <translation>Toista</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="47"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="50"/>
         <source>Frequency</source>
         <translation>Toistuminen</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="58"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="61"/>
         <source>Daily</source>
         <translation>Päivittäin</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="63"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="66"/>
         <source>Weekly</source>
         <translation>Viikoittain</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="68"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="71"/>
         <source>Monthly</source>
         <translation>Kuukausittain</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="73"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="76"/>
         <source>Yearly</source>
         <translation>Vuosittain</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="81"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="84"/>
         <source>Interval</source>
         <translation>Aikaväli</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="105"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="108"/>
         <source>Forever</source>
         <translation>Ikuisesti</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="110"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="113"/>
         <source>Until</source>
         <translation>Saakka</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="115"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="118"/>
         <source>Count</source>
         <translation>Kertaa</translation>
     </message>
@@ -748,25 +748,25 @@ päivä</translation>
         <location filename="../settings/SettingsDialog.cpp" line="45"/>
         <location filename="../settings/SettingsDialog.cpp" line="47"/>
         <source>Older than %n week(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>Vanhempi kuin %n viikko</numerusform>
+            <numerusform>Vanhempi kuin %n viikkoa</numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../settings/SettingsDialog.cpp" line="49"/>
         <source>Older than %n month(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>Vanhempi kuin %n kuukausi</numerusform>
+            <numerusform>Vanhempi kuin %n kuukautta</numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../settings/SettingsDialog.cpp" line="51"/>
         <source>Older than %n year(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>Vanhempi kuin %n vuosi</numerusform>
+            <numerusform>Vanhempi kuin %n vuotta</numerusform>
         </translation>
     </message>
 </context>
@@ -840,37 +840,37 @@ päivä</translation>
 <context>
     <name>TodosPlug</name>
     <message>
-        <location filename="../TodosPlug.cpp" line="34"/>
+        <location filename="../TodosPlug.cpp" line="33"/>
         <source>New task</source>
         <translation>Uusi tehtävä</translation>
     </message>
     <message>
-        <location filename="../TodosPlug.cpp" line="44"/>
+        <location filename="../TodosPlug.cpp" line="40"/>
         <source>Hide completed</source>
         <translation>Piilota valmiit</translation>
     </message>
     <message>
-        <location filename="../TodosPlug.cpp" line="45"/>
+        <location filename="../TodosPlug.cpp" line="41"/>
         <source>Delete completed</source>
         <translation>Poista valmiit</translation>
     </message>
     <message>
-        <location filename="../TodosPlug.cpp" line="82"/>
+        <location filename="../TodosPlug.cpp" line="78"/>
         <source>Tasks</source>
         <translation>Tehtävät</translation>
     </message>
     <message>
-        <location filename="../TodosPlug.cpp" line="202"/>
+        <location filename="../TodosPlug.cpp" line="198"/>
         <source>Edit</source>
         <translation>Muokkaa</translation>
     </message>
     <message>
-        <location filename="../TodosPlug.cpp" line="203"/>
+        <location filename="../TodosPlug.cpp" line="199"/>
         <source>Delete</source>
         <translation>Poista</translation>
     </message>
     <message>
-        <location filename="../TodosPlug.cpp" line="228"/>
+        <location filename="../TodosPlug.cpp" line="224"/>
         <source>Delete completed tasks from all calendars?</source>
         <translation>Poista suoritetut tehtävät kaikista kalentereista?</translation>
     </message>
@@ -919,7 +919,7 @@ päivä</translation>
 <context>
     <name>WeekWidget</name>
     <message>
-        <location filename="../week/WeekWidget.cpp" line="349"/>
+        <location filename="../week/WeekWidget.cpp" line="348"/>
         <source>All day</source>
         <translation>Koko päivä</translation>
     </message>
